@@ -70,12 +70,22 @@ class FreqDict(models.Model):
         wfs = self.loadOrthWF()
         wfs = self.loadTransWF(wfs)
         wfss = []
+        ts = []
+        ss = []
         for key in wfs:
             lem = Lemma.objects.filter(pk=int(wfs[key]['IdLemma']))
             if len(lem) != 1:
                 continue
             wfss.append(WordForm(pk=int(key),Lemma = lem[0],Frequency = int(wfs[key]['Freq'])))
+            ts.extend([Transcription(Transcription=t
+                    ,CVSkel=re.sub('[^IE{VQU@i#$u312456789cq0~]','C',
+                                re.sub('[IE{VQU@i#$u312456789cq0~]','V',
+                                re.sub(r'[-"\']','',t))))
+                    for t in wfs[key]['Transcriptions']])
+            ss.extend(Orthography(Spelling=s) for s in wfs[key]['Spellings'])
         WordForm.objects.bulk_create(wfss)
+        Transcription.objects.bulk_create(ts)
+        Orthography.objects.bulk_create(ss)
         for w in wfss:
             #ts = [Transcription(Transcription=t
             #        ,CVSkel=re.sub('[^IE{VQU@i#$u312456789cq0~]','C',
@@ -88,13 +98,9 @@ class FreqDict(models.Model):
             #Orthography.objects.bulk_create(ss)
             #w.Orthographies.add(*ss)
             #wf = WordForm.objects.create(pk=int(key),Lemma = lem[0],Frequency = int(wfs[key]['Freq']))
-            ss = (Orthography.objects.get_or_create(Spelling=s)[0] for s in wfs[str(w.pk)]['Spellings'])
+            ss = list(Orthography.objects.filter(Spelling__in = wfs[str(w.pk)]['Spellings']))
             w.Orthographies.add(*ss)
-            ts = (Transcription.objects.get_or_create(Transcription=t
-                    ,defaults={'CVSkel':re.sub('[^IE{VQU@i#$u312456789cq0~]','C',
-                                re.sub('[IE{VQU@i#$u312456789cq0~]','V',
-                                    re.sub(r'[-"\']','',t)))})[0]
-                        for t in wfs[str(w.pk)]['Transcriptions'])
+            ss = list(Transcription.objects.filter(Transcription__in = wfs[str(w.pk)]['Transcriptions']))
             w.Transcriptions.add(*ts)
 
     def loadOrthLemmas(self):
